@@ -15,7 +15,7 @@ use ORLite                  ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.06';
+	$VERSION = '0.07';
 	@ISA     = qw{ ORLite };
 }
 
@@ -27,7 +27,14 @@ BEGIN {
 # Code Generation
 
 sub import {
-	my $class = ref($_[0]) || $_[0];
+	my $class = ref $_[0] || $_[0];
+
+	# Check for debug mode
+	my $DEBUG = 0;
+	if ( defined _STRING($_[-1]) and $_[-1] eq '-DEBUG' ) {
+		$DEBUG = 1;
+		pop @_;
+	}
 
 	# Check params and apply defaults
 	my %params;
@@ -47,21 +54,33 @@ sub import {
 		$params{package} = scalar caller;
 	}
 
-	# Determine the mirror database path
-	my $file = $params{package} . '.sqlite';
-	$file =~ s/::/-/g;
+	# Check when we should update
+	unless ( defined $params{update} ) {
+		$params{update} = 'compile';
+	}
+	unless ( $params{update} =~ /^(?:compile|connect)$/ ) {
+		Carp::croak("Invalid update param '$params{update}'");
+	}
 
-	# Create the directory
+	# Determine the mirror database location
 	my $dir = File::Spec->catdir(
 		File::HomeDir->my_data,
 		'Perl', 'ORLite-Mirror'
 	);
+	my $file = $params{package} . '.sqlite';
+	$file =~ s/::/-/g;
+	my $path = File::Spec->catfile( $dir, $file );
+	unless ( -f $path ) {
+		# If the file doesn't exist, sync at compile time.
+		$params{update} = 'compile';
+	}
+
+	# Create the directory
 	unless ( -e $dir ) {
 		File::Path::mkpath( $dir, { verbose => 0 } );
 	}
 
 	# Create the default useragent
-	my $path      = File::Spec->catfile( $dir, $file );
 	my $useragent = delete $params{useragent};
 	unless ( $useragent ) {
 		my $version = $params{package}->VERSION || 0;
@@ -108,7 +127,28 @@ sub import {
 	$params{readonly} = 1;
 
 	# Hand off to the main ORLite class.
-	$class->SUPER::import( \%params );
+	my $rv = $class->SUPER::import( \%params, $DEBUG ? '-DEBUG' : () );
+
+	# If and only if they update at connect-time, replace the
+	# original dbh method with one that syncs the database.
+	if ( $params{update} eq 'connect' ) {
+		my $code = <<"END_PERL";
+package $params{package};
+
+use vars qw{ \$SYNCED };
+BEGIN {
+	\$SYNCED = 0;
+	delete \$$params{package}::{DBH};
+}
+
+sub connect {
+	my $class = shift;
+	
+}
+END_PERL
+	}
+
+	return $rv;
 }
 
 1;
